==> packagekit_1.3.3.orig.tar.xz: PackageKit-1.3.3/README.md <==
PackageKit
==========
<img align="right" src="docs/html/img/packagekit.png">

[![Build Test](https://github.com/PackageKit/PackageKit/actions/workflows/build-test.yml/badge.svg)](https://github.com/PackageKit/PackageKit/actions/workflows/build-test.yml)
[![Translation status](https://hosted.weblate.org/widget/packagekit/svg-badge.svg)](https://hosted.weblate.org/engage/packagekit/)

PackageKit is a DBus abstraction layer that allows the session user to manage
packages in a secure way using a cross-distro, cross-architecture API.

Its primary design goal is to unify all the software graphical tools used in different distributions,
and use some of the latest technology like PolicyKit.

Download releases at: [freedesktop.org/software/PackageKit/releases/](https://www.freedesktop.org/software/PackageKit/releases/)

For more information, please see: [freedesktop.org/software/PackageKit/](https://www.freedesktop.org/software/PackageKit/)

### Contributing

We welcome your contributions!
Please read the [CONTRIBUTING](CONTRIBUTING) file first to get started when creating a pull-request.

Each backend for PackageKit is maintained by a backend-maintainer, usually from the distribution
the backend adds support for. You can find a list of who maintains what at [backends/MAINTAINERS.md](backends/MAINTAINERS.md).

If you file a bug that affects a specific backend, please tag it with the respective tag.


### Translations

Translation of this project is done via Weblate. Please check out [hosted.weblate.org/projects/packagekit/](https://hosted.weblate.org/projects/packagekit/)
for the translation project for PackageKit.

==> packagekit_1.3.4.orig.tar.xz: PackageKit-1.3.4/README.md <==
PackageKit
==========
<img align="right" src="docs/html/img/packagekit.png">

[![Build Test](https://github.com/PackageKit/PackageKit/actions/workflows/build-test.yml/badge.svg)](https://github.com/PackageKit/PackageKit/actions/workflows/build-test.yml)
[![Translation status](https://hosted.weblate.org/widget/packagekit/svg-badge.svg)](https://hosted.weblate.org/engage/packagekit/)

PackageKit is a D-Bus abstraction layer that allows the session user to manage
packages in a secure way using a cross-distro, cross-architecture API.

Its primary design goal is to unify all the software graphical tools used in different distributions,
and use some of the latest technology like PolicyKit.

Download releases at: [freedesktop.org/software/PackageKit/releases/](https://www.freedesktop.org/software/PackageKit/releases/)

For more information, please see: [freedesktop.org/software/PackageKit/](https://www.freedesktop.org/software/PackageKit/)

### Contributing

We welcome your contributions!
Please read the [CONTRIBUTING](CONTRIBUTING) file first to get started when creating a pull-request.

Each backend for PackageKit is maintained by a backend-maintainer, usually from the distribution
the backend adds support for. You can find a list of who maintains what at [backends/MAINTAINERS.md](backends/MAINTAINERS.md).

If you file a bug that affects a specific backend, please tag it with the respective tag.


### Translations

Translation of this project is done via Weblate. Please check out [hosted.weblate.org/projects/packagekit/](https://hosted.weblate.org/projects/packagekit/)
for the translation project for PackageKit.
